Package: fishstat
Version: 2026.1.0.0
Date: 2026-04-04
Title: Global Fishery and Aquaculture Statistics
Authors@R: c(person("Arni", "Magnusson", role=c("aut","cre"), email="thisisarni@gmail.com"),
             person("Rishi", "Sharma", role="aut"),
             person("FAO", role="cph"))
Depends: R (>= 3.5.0)
Suggests: areaplot
LazyData: yes
Description: The Food and Agriculture Organization of the United Nations (FAO)
  FishStat database is the leading source of global fishery and aquaculture
  statistics and provides unique information for sector analysis and monitoring.
  This package provides the global production data from all fisheries and
  aquaculture in R format, ready for analysis.
License: CC BY-NC-SA 4.0
URL: https://www.fao.org/fishery/en/fishstat,
        https://github.com/sofia-taf/fishstat
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-04 12:19:42 UTC; arnim
Author: Arni Magnusson [aut, cre],
  Rishi Sharma [aut],
  FAO [cph]
Maintainer: Arni Magnusson <thisisarni@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-04 12:50:02 UTC
Built: R 4.6.0; ; 2026-04-25 18:55:20 UTC; unix
